import { Subject } from 'rxjs';
import { DashboardViewBase } from '@/studio-core';
import HROMHierarchyCatService from '@/service/hromhierarchy-cat/hromhierarchy-cat-service';
import HROMHierarchyCatAuthService from '@/authservice/hromhierarchy-cat/hromhierarchy-cat-auth-service';
import PortalViewEngine from '@engine/view/portal-view-engine';
import HROMHierarchyCatUIService from '@/uiservice/hromhierarchy-cat/hromhierarchy-cat-ui-service';

/**
 * 结构层次类别看板视图基类
 *
 * @export
 * @class HROMHierarchyCatDashboardViewBase
 * @extends {DashboardViewBase}
 */
export class HROMHierarchyCatDashboardViewBase extends DashboardViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HROMHierarchyCatDashboardViewBase
     */
    protected appDeName: string = 'hromhierarchycat';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HROMHierarchyCatDashboardViewBase
     */
    protected appDeKey: string = 'omhierarchycatid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HROMHierarchyCatDashboardViewBase
     */
    protected appDeMajor: string = 'omhierarchycatname';

    /**
     * 实体服务对象
     *
     * @type {HROMHierarchyCatService}
     * @memberof HROMHierarchyCatDashboardViewBase
     */
    protected appEntityService: HROMHierarchyCatService = new HROMHierarchyCatService;

    /**
     * 实体权限服务对象
     *
     * @type HROMHierarchyCatUIService
     * @memberof HROMHierarchyCatDashboardViewBase
     */
    public appUIService: HROMHierarchyCatUIService = new HROMHierarchyCatUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HROMHierarchyCatDashboardViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HROMHierarchyCatDashboardViewBase
     */
    protected model: any = {
        srfCaption: 'entities.hromhierarchycat.views.dashboardview.caption',
        srfTitle: 'entities.hromhierarchycat.views.dashboardview.title',
        srfSubTitle: 'entities.hromhierarchycat.views.dashboardview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HROMHierarchyCatDashboardViewBase
     */
    protected containerModel: any = {
        view_dashboard: { name: 'dashboard', type: 'DASHBOARD' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'c62ff001669cca98c0a2a7bc3383c775';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HROMHierarchyCatDashboardViewBase
     */
    public engine: PortalViewEngine = new PortalViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HROMHierarchyCatDashboardViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            dashboard: this.$refs.dashboard,
            keyPSDEField: 'hromhierarchycat',
            majorPSDEField: 'omhierarchycatname',
            isLoadDefault: true,
        });
    }

    /**
     * dashboard 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROMHierarchyCatDashboardViewBase
     */
    public dashboard_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('dashboard', 'load', $event);
    }


}